@@ -7,7 +7,7 @@
 /**
  * Class representing iCalendar files.
  *
- * Copyright 2003-2011 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2013 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -555,6 +555,8 @@ class Horde_Icalendar
             $this->clear();
         }
 
+        $text = Horde_String::trimUtf8Bom($text);
+
         if (preg_match('/^BEGIN:' . $base . '(.*)^END:' . $base . '/ism', $text, $matches)) {
             $container = true;
             $vCal = $matches[1];
@@ -568,7 +570,7 @@ class Horde_Icalendar
 
         // Extract all subcomponents.
         $matches = $components = null;
-        if (preg_match_all('/^BEGIN:(.*)(\r\n|\r|\n)(.*)^END:\1/Uims', $vCal, $components)) {
+        if (preg_match_all('/^BEGIN:(.*)\s*?(\r\n|\r|\n)(.*)^END:\1\s*?/Uims', $vCal, $components)) {
             foreach ($components[0] as $key => $data) {
                 // Remove from the vCalendar data.
                 $vCal = str_replace($data, '', $vCal);
@@ -1220,10 +1222,10 @@ class Horde_Icalendar
 
         $change_times = array();
         foreach ($vtimezone->getComponents() as $o) {
-            $t = $vtimezone->parseChild($o, $date['year']);
-            if ($t !== false) {
-                $change_times[] = $t;
-            }
+            $change_times = array_merge(
+                $change_times,
+                $vtimezone->parseChild($o, $date['year'])
+            );
         }
 
         if (!$change_times) {
@@ -1266,12 +1268,12 @@ class Horde_Icalendar
      *
      * @return TODO
      */
-    protected function _parseDateTime($text, $tzid = false)
+    public function _parseDateTime($text, $tzid = false)
     {
         $dateParts = explode('T', $text);
         if (count($dateParts) != 2 && !empty($text)) {
             // Not a datetime field but may be just a date field.
-            if (!preg_match('/^(\d{4})-?(\d{2})-?(\d{2})$/', $text, $match)) {
+            if (!preg_match('/^(\d{4})-?(\d{2})-?(\d{2})$/', $text)) {
                 // Or not
                 return $text;
             }
@@ -1315,8 +1317,7 @@ class Horde_Icalendar
      *                                     Horde_Date, array, or timestamp).
      * @param boolean $floating            Whether to return a floating
      *                                     date-time (without time zone
-     *                                     information). @since Horde_Icalendar
-     *                                     1.0.5.
+     *                                     information).
      *
      * @return string  The string representation of the datetime value.
      */
@@ -1354,7 +1355,7 @@ class Horde_Icalendar
      *
      * @return array TODO
      */
-    protected function _parseDate($text)
+    public function _parseDate($text)
     {
         $parts = explode('T', $text);
         if (count($parts) == 2) {
